--table.lua

function array2string(t)
	local str = ""
	
	for i,v in ipairs(t) do
		str = str..i..","..t[i]..","
	end
	
	return str
end

function string2array(str)
	local t = {}
	
	for i,v in string.gmatch(str, "(%d+),(.-),") do
		if i then t[tonumber(i)] = v or "" end
	end
	
	return t
end

function hash2string(t)
	local str = ""
	
	for k,v in pairs(t) do
		str = str..k..","..t[k]..","
	end
	
	return str
end

function string2hash(str)
	local t = {}
	
	for k,v in string.gmatch(str, "(.--),(.-),") do
		if k then t[k] = v or "" end
	end
	
	return t
end

function table2string(t)
	local str = ""
	
	for k,v in pairs(t) do
		if type(k) == "number" then
			str = str..k..",,"..v..","
		else
			str = str..","..k..","..v..","
		end
	end
	
	return str
end

function string2table(str)
	local t = {}
	
	for i,k,v in string.gmatch(str, "(.-),(.-),(.-),") do
		if i or k then
			if tonumber(i) then
				t[tonumber(i)] = v or ""
			else
				t[k] = v or ""
			end
		end
	end
	
	return t
end

function array2csv(t, filename)
	local file = io.open(filename, "w")
	
	for i,v in ipairs(t) do
		file:write(i..","..v.."\n")
	end
	
	file:close()
end

function csv2array(filename)
	local t = {}
	
	for line in io.lines(filename) do
		local i,v = string.match(line, "(%d+),(..-)")
		if i and i ~= "" then t[tonumber(i)] = v or "" end
	end
	
	return t
end

function hash2csv(t, filename)
	local file = io.open(filename, "w")
	
	for k,v in pairs(t) do
		file:write(k..","..v.."\n")
	end
	
	file:close()
end

function csv2hash(filename)
	local t = {}
	
	for line in io.lines(filename) do
		local k,v = string.match(line, "(..-),(..-)")
		if k then t[k] = v or "" end
	end
	
	return t
end

function table2csv(t, filename)
	local file = io.open(filename, "w")
	
	for k,v in pairs(t) do
		if type(k) == "number" then
			file:write(k..",,"..v.."\n")
		else
			file:write(","..k..","..v.."\n")
		end
	end
	
	file:close()
end

function csv2table(filename)
	local t = {}
	
	for line in io.lines(filename) do
		if string.find(line, "^%d+,,.-") then 
			local i,v = string.match(line, "^(%d+),,(.*)")
			t[tonumber(i)] = v or ""
		elseif string.find(line,"^,..-,.-") then
			local k,v = string.match(line,"^,(..-),(.*)")
			t[k] = v or ""
		end
	end
	
	return t
end

